@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -83,14 +83,6 @@ struct DelayTaggedUpdater {
     int incr;
 };
 
-void
-DelayTaggedUpdateWalkee(DelayTaggedBucket::Pointer const &current, void *state)
-{
-    DelayTaggedUpdater *t = (DelayTaggedUpdater *)state;
-    /* This doesn't change the value of the DelayTaggedBucket, so is safe */
-    const_cast<DelayTaggedBucket *>(current.getRaw())->theBucket.update(t->spec, t->incr);
-}
-
 struct DelayTaggedUpdateVisitor {
     DelayTaggedUpdater *updater;
     explicit DelayTaggedUpdateVisitor(DelayTaggedUpdater *u) : updater(u) {}
@@ -173,7 +165,7 @@ DelayTagged::Id::bytesIn(int qty)
 }
 
 void
-DelayTagged::Id::delayRead(DeferredRead const &aRead)
+DelayTagged::Id::delayRead(const AsyncCall::Pointer &aRead)
 {
     theTagged->delayRead(aRead);
 }
